#!/usr/bin/env python3

import openai
import requests
import json
import base64
import os
from datetime import datetime

openai.api_key = os.environ["OPENAI_API_KEY"] # Set your API key as an environment variable

def generate_image(prompt):
    headers = {
        "Content-Type": "application/json",
        "Authorization": f"Bearer {openai.api_key}",
    }
    data = {
        "model": "image-alpha-001",
        "prompt": prompt,
        "num_images": 1,
        "size": "512x512",
        "response_format": "url",
    }
    response = requests.post("https://api.openai.com/v1/images/generations", headers=headers, data=json.dumps(data))
    response.raise_for_status()
    response_data = response.json()
    image_url = response_data["data"][0]["url"]
    return image_url

def save_image(image_url):
    response = requests.get(image_url)
    image_data = response.content
    image_name = datetime.now().strftime("%Y-%m-%d_%H-%M-%S") + ".png"
    with open(image_name, "wb") as f:
        f.write(image_data)
    print(f"Image saved as {image_name}")

def main():
    prompt = input("Enter a prompt: ")
    image_url = generate_image(prompt)
    save_image(image_url)

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    name='termai',
    version='0.1.1.1.1',
    author='Brad Ganley',
    author_email='bradganley@pm.me',
    description='A package for generating and manipulating text and images using OpenAI.',
    packages=find_packages(),
    install_requires=[
        'click==8.0.1',
        'openai==0.10.5',
        'requests==2.26.0',
        'Pillow==8.3.2'
    ],
    entry_points={"console_scripts": ["termchat = termai.cli:cli"]}
    )



#!/usr/bin/env python
import openai
import sys
import os

openai.api_key = os.getenv("OPENAI_API_KEY")

def send_message(message):
    response = openai.Completion.create(model="text-davinci-003", prompt=message, max_tokens=200)
    return response.choices[0].text.strip()

def read_input():
    if not sys.stdin.isatty():
        return sys.stdin.read().strip()
    elif len(sys.argv) > 1:
        return sys.argv[1]
    else:
        return ""

input_data = read_input()

if input_data:
    user_input = f"Here's the output of a command: {input_data}. {sys.argv[1]}"
    response = send_message(user_input)
    print(response)
else:
    user_input = input("You: ")
    response = send_message(user_input)
    print(response)
